### Name: backfitRichards-package
### Title: Backfitted independent values of Richards curves
### Aliases: backfitRichards-package backfitRichards
### Keywords: package

### ** Examples


## Not run: 

library(nlme)

data(ChickWeight)

ChickWeight <- cbind(ChickWeight, ExpTime = exp(ChickWeight[,"Time"]))

groupedChicks <- groupedData(weight ~ ExpTime | Diet / Chick, 
                             inner = ~ PR, data = ChickWeight)

listChicks <- split(groupedChicks, list(groupedChicks[,"Diet"],
                                        groupedChicks[,"Chick"]),
                    drop = TRUE)

fit.Fpl.BP <- function(X, start, lower, upper)
 {
  try(nls(weight ~ SSny1(ExpTime, a, d, b, x50),
          lower = lower, upper = upper, algorithm = "port",
          control = nls.control(warnOnly = TRUE), data = X))
 }

Start <- list(a =    25, d =  200, b =  10, x50 =    10, ny =  1)
Lower <- list(a = -2000, d =    5, b =   0, x50 =     1, ny =  0.01)
Upper <- list(a =    50, d = 1500, b =  50, x50 = 10^20, ny = 128)

myApplyFUN2X <- 
  function(X, FUN, start = Start, lower = Lower, upper = Upper,
              Report = print, ...) {
    if (dim(X)[1] > 0) {
      result <- FUN(X, start, lower, upper)
      if (is.null(result) | class(result) == "try-error")
        Report(X)
      return(result)
    }
  }

fits.Fpl.BP <- lamodified(listChicks, FUN = fit.Fpl.BP, n = 4,
                          applyFUN2X = myApplyFUN2X)

back.Fits <- backFits(listChicks, FUN = fit.Fpl.BP, ny = 1,
                      respName = "weight", indepName = "ExpTime",
                      applyFUN2X = myApplyFUN2X)

par(mfrow = c(2, 2))

Z.back <- backPlot(backFits = back.Fits, xt = function(x) x,
                   main = "Relative backfitted exp(time)", xlab = "Exp(Time)", 
                   ylim = c(0, 500), log = "x", pch = 1, col = "red")

Z.back <- backPlot(backFits = back.Fits, xt = function(x) log(x),
                   main = "Relative backfitted exp(time)", xlab = "Time", 
                   ylim = c(0, 500), pch = 1, col = "red")

Z.back <- backPlot(backFits = back.Fits, xt = function(x) log(x),
                   main = "Relative backfitted exp(time)", xlab = "Time", 
                   log = "y", ylim = c(1, 5000), pch = 1, col = "red")

Z.back <- backPlot(backFits = back.Fits, xt = function(x) log(x),
                   main = "Relative backfitted exp(time)", xlab = "Time", 
                   log = "y", ylim = c(10, 500), pch = 1, col = "red")

## End(Not run)




